@@ -69,7 +69,7 @@ def combine(in_files, out_file, verbose=False, replace = None):
     console.confirm( "  Generating %s" % out_file)
     writefile(out_file, combined)
 
-def minify(in_file, out_file = None, verbose=False, strict=False):
+def minify(in_file, out_file = None, verbose=False, strict=True, ecma3=False):
 
     System.check_package('java')
 
@@ -86,7 +86,7 @@ def minify(in_file, out_file = None, verbose=False, strict=False):
     console.header('- Minifying %s (%.2f kB)' % (__pretty(in_file), org_size / 1024.0))
 
     if in_type == 'js':
-        __minify_js(in_file, out_file + '.tmp', verbose, strict)
+        __minify_js(in_file, out_file + '.tmp', verbose, strict, ecma3)
     else:
         __minify_css(in_file, out_file + '.tmp', verbose)
     
@@ -120,8 +120,11 @@ def jslint(files, fix = False, relax = False, fail = True):
     options.append('--jslint_error=optional_type_marker')
     options.append('--jslint_error=blank_lines_at_top_level')
     options.append('--jslint_error=indentation')
-    options.append('--custom_jsdoc_tags=homepage,version,ignore,returns,example,function,requires,name,namespace,property,static,constant,default,location,copyright,memberOf,lends,fileOverview')
-
+    # This covers jsdoctoolkit 2
+    tags = '--custom_jsdoc_tags=homepage,version,ignore,returns,example,function,requires,name,namespace,property,static,constant,default,location,copyright,memberOf,lends,fileOverview'
+    # This covers jsdoc3 as well
+    tags += ',file,kind,summary,description,event,exception,exports,fires,global,inner,instance,member,var,memberof,mixes,mixin,arg,argument,readonly,since,todo,public'
+    options.append(tags)
 
     if fix == True:
         header = "Fix JS lint"
@@ -140,6 +143,37 @@ def jslint(files, fix = False, relax = False, fail = True):
         console.fail( ' :puke:\n' + error.group())
 
 
+def jsdoc3(files, destination, template = None, fail = True):
+    System.check_package('java')
+
+    files = FileList.check(files)
+
+    redirect = ''
+
+    if not template:
+        template = "templates/haruki"
+
+    if template == "templates/haruki":
+        redirect = destination
+        destination = "console"
+
+    jsdoc =  os.path.join(__get_datas_path(), 'jsdoc3-jsdoc-1c6ff94')
+    out = Std()
+    output = sh('cd "%s"; java -classpath lib/js.jar org.mozilla.javascript.tools.shell.Main -debug -modules nodejs_modules -modules rhino_modules -modules . jsdoc.js\
+      --destination "%s" --template "%s" %s' % (jsdoc, destination, template, '"' + '" "'.join(files) + '"'), header = "Generating js doc v3", output = False, std = out)
+
+    if fail and out.code:
+        console.fail(out.err)
+    
+    if template == "templates/haruki":
+        writefile(redirect, out.out);
+        console.confirm('  JSON Doc generated in "%s"' % redirect)
+    else:
+        console.confirm('  JSON Doc generated in "%s"' % destination)
+
+    return out.out
+
+
 def jsdoc(files, folder, template = None, fail = True):
     System.check_package('java')
 
@@ -443,16 +477,18 @@ def __parse_scss(payload):
     css = Scss()
     return css.compile(payload)
 
-def __minify_js(in_file, out_file, verbose, strict=False):
+def __minify_js(in_file, out_file, verbose, strict=True, ecma3=False):
     options = ['--js %s' % in_file,
                '--js_output_file %s' % out_file,
                '--warning_level QUIET']
+    if ecma3 == True:
+        options.append('--language_in ECMASCRIPT3')
+    elif strict == True:
+        options.append('--language_in ECMASCRIPT5_STRICT')
+    else:
+        options.append('--language_in ECMASCRIPT5')
 
-    if strict == True:
-        options.append('--language_in=ECMASCRIPT5_STRICT')
-
-    os.system('java -jar "%s" %s' % (JS_COMPRESSOR,
-                                          ' '.join(options)))
+    os.system('java -jar "%s" %s' % (JS_COMPRESSOR, ' '.join(options)))
 
 def __get_datas_path():
     return os.path.join(os.path.dirname( __file__ ), 'datas')
